# Generated by Django 5.1.1 on 2024-09-20 17:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('channels', '0005_customerchannel'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerchannel',
            name='order',
            field=models.PositiveSmallIntegerField(default=1),
            preserve_default=False,
        ),
    ]
